# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.0.5] - 2022-01-14
### Fix
- Installation: remove cryptofeed requirement in OctoBot

## [0.0.4] - 2022-30-12
### Added
- Report generation time

## [0.0.3] - 2022-29-12
### Fixed
- Install

## [0.0.2] - 2022-29-12
### Updated
- Install method

## [0.0.1] - 2022-10-12
### Added
- OctoBot Pro alpha version
